/*-
 * %%----------------------------------------------------------------------------------------------
 * Solidify Framework - Solidify Frontend - ssr-interceptor.service.ts
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2023 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

/* eslint-disable no-console */

import {
  HttpEvent,
  HttpHandler,
  HttpInterceptor,
  HttpRequest,
} from "@angular/common/http";
import {
  Inject,
  Injectable,
} from "@angular/core";
import {Observable} from "rxjs";
import {DefaultSolidifyEnvironment} from "../environments/environment.solidify-defaults";
import {ENVIRONMENT} from "../injection-tokens/environment.injection-token";
import {AbstractBaseService} from "../services/abstract-base.service";
import {SsrUtil} from "../utils/ssr.util";

@Injectable({
  providedIn: "root",
})
export class SsrInterceptorService extends AbstractBaseService implements HttpInterceptor {
  constructor(@Inject(ENVIRONMENT) private readonly _environment: DefaultSolidifyEnvironment) {
    super();
  }

  public intercept(req: HttpRequest<any>, next: HttpHandler, noRetry: boolean = false): Observable<HttpEvent<any>> {
    if (SsrUtil.isServer) {
      this._log(`[${req.method}] ${req.url}: Intercept request`);

      if (req.url.startsWith("./") || req.url.startsWith("/") || req.url.startsWith("assets/")) {
        const modifiedReq = req.clone({
          url: `http://localhost:${SsrUtil.port}/` + req.url,
        });
        this._log(`[${req.method}] ${req.url}: Intercept request updated into '${modifiedReq.url}'`);

        return next.handle(modifiedReq);
      }
      this._log(`[${req.method}] ${req.url}: Intercept request not updated`);
    }
    return next.handle(req);
  }

  private _log(message: string): void {
    if (this._environment.showDebugInformation) {
      console.log(message);
    }
  }
}
